ANT2: Messy ANT data

ANT2R Documentation

Messy ANT data

Description

A “messy” version of the ANT data set (see ANT). In this version of the data, subnum #7 is missing data from the last half of the experiment, subnum #14 made all errors in the incongruent cells, and subnum #12 mistakenly reversed their responses.

Usage

data(ANT2)

Author(s)

Michael A. Lawrence mike.lwrnc@gmail.com
Visit the ez development site at https://github.com/mike-lawrence/ez
for the bug/issue tracker and the link to the mailing list.

Examples

data(ANT2)
head(ANT2)
ezPrecis(ANT2)

ez documentation built on Feb. 16, 2026, 5:06 p.m.