Learn R Programming

ez (version 2.0-0)

ez-package: Easy analysis and visualization of factorial experiments.

Description

This package facilitates easy analysis of factorial experiments, including purely within-Ss designs (a.k.a. "repeated measures"), purely between-Ss designs, and mixed within-and-between-Ss designs. The functions in this package aim to provide simple, intuitive and consistent specification of data analysis and visualization. Visualization functions also include design visualization for pre-analysis data auditing, and correlation matrix visualization. Finally, this package includes functions for non-parametric analysis, including permutation tests and bootstrap resampling. The bootstrap function obtains predictions either by cell means or by more advanced/powerful mixed effects models, yielding predictions and confidence intervals that may be easily visualized at any level of the experiment's design.

Arguments

Details

ll{ Package: ez Type: Package Version: 2.0-0 Date: 2010-08-30 License: GPL-3 LazyLoad: yes } This package contains several useful functions: {Provides simple interface to ANOVA, including assumption checks.} ezBoot{Computes bootstrap resampled cell means or lmer predictions} ezCor{Function to plot a correlation matrix with scatterplots, linear fits, and univariate density plots} ezDesign{Function to plot a visual representation of the balance of data given a specified experimental design. Useful for diagnosing missing data issues.} ezPerm{Provides simple interface to the Permutation test.} ezPlot{Uses the ggplot2 graphing package to generate plots for any given user-requested effect, by default producing error bars that facilitate visual post-hoc multiple comparisons.} ezPlotBoot{When supplied the results from a call to ezBoot, plots predictions with bootstrapped confidence intervals.} ezPrecis{Provides a summary of a given data frame.} ezStats{Provides between-Ss descriptive statistics for any given user-requested effect.} This package also contains two data sets: ANT{Simulated data from the Attention Network Test} ANT2{Messy version of the ANT data set}

See Also

ANT, ANT2, ezANOVA, ezBoot, ezCor, ezDesign, ezPerm, ezPlot, ezPlotBoot, ezPrecis, ezStats