| ANT2 | R Documentation |
A “messy” version of the ANT data set (see ANT). In this version of the data, subnum #7 is missing data from the last half of the experiment, subnum #14 made all errors in the incongruent cells, and subnum #12 mistakenly reversed their responses.
data(ANT2)
Michael A. Lawrence mike.lwrnc@gmail.com
Visit the ez development site at https://github.com/mike-lawrence/ez
for the bug/issue tracker and the link to the mailing list.
data(ANT2)
head(ANT2)
ezPrecis(ANT2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.