powered by
Internal functions for the ez package.
ez
Michael A. Lawrence mike.lwrnc@gmail.com Visit the ez development site at https://github.com/mike-lawrence/ez for the bug/issue tracker and the link to the mailing list.
These are not to be called by the user.