| ez-package | R Documentation |
This package facilitates easy analysis of factorial experiments, including purely within-Ss designs (a.k.a. “repeated measures”), purely between-Ss designs, and mixed within-and-between-Ss designs. The functions in this package aim to provide simple, intuitive and consistent specification of data analysis and visualization. Visualization functions also include design visualization for pre-analysis data auditing, and correlation matrix visualization. Finally, this package includes functions for non-parametric analysis, including permutation tests and bootstrap resampling. The bootstrap function obtains predictions either by cell means or by more advanced/powerful mixed effects models, yielding predictions and confidence intervals that may be easily visualized at any level of the experiment's design.
| Package: | ez |
| Type: | Package |
| Version: | 4.5-0 |
| Date: | 2016-11-01 |
| License: | GPL-3 |
| LazyLoad: | yes |
This package contains several useful functions:
ezANOVAProvides simple interface to ANOVA, including assumption checks.
ezBootComputes bootstrap resampled cell means or lmer predictions
ezCorFunction to plot a correlation matrix with scatterplots, linear fits, and univariate density plots
ezDesignFunction to plot a visual representation of the balance of data given a specified experimental design. Useful for diagnosing missing data issues.
ezMixedProvides assessment of fixed effects in a mixed effects modelling context.
ezPermProvides simple interface to the Permutation test.
ezPlot Uses the ggplot2 graphing package to generate plots for any given user-requested effect, by default producing error bars that facilitate visual post-hoc multiple comparisons.
ezPlot2 When supplied the results from a call to ezPredict or ezBoot, plots predictions with confidence intervals.
ezPrecisProvides a summary of a given data frame.
ezPredictComputes predicted values from the fixed effects of a mixed effects model.
ezResampleResamples data, useful when bootstrapping.
ezStatsProvides between-Ss descriptive statistics for any given user-requested effect.
This package also contains two data sets:
ANTSimulated data from the Attention Network Test
ANT2Messy version of the ANT data set
Michael A. Lawrence mike.lwrnc@gmail.com
Visit the ez development site at https://github.com/mike-lawrence/ez
for the bug/issue tracker and the link to the mailing list.
ANT, ANT2, ezANOVA, ezBoot, ezCor, ezDesign, ezMixed, ezPerm, ezPlot, ezPlot2, ezPrecis, ezPredict, ezResample, ezStats
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.