ez-package: Easy analysis and visualization of factorial experiments
Description
This package facilitates easy analysis of factorial experiments, including purely within-Ss designs (a.k.a. repeated measures), purely between-Ss designs, and mixed within-and-between-Ss designs. The functions in this package aim to provide simple, intuitive and consistent specification of data analysis and visualization. Visualization functions also include design visualization for pre-analysis data auditing, and correlation matrix visualization. Finally, this package includes functions for non-parametric analysis, including permutation tests and bootstrap resampling. The bootstrap function obtains predictions either by cell means or by more advanced/powerful mixed effects models, yielding predictions and confidence intervals that may be easily visualized at any level of the experiment's design.Details
ll{
Package: ez
Type: Package
Version: 4.1.1
Date: 2012-08-11
License: GPL-3
LazyLoad: yes
}
This package contains several useful functions:
{ Provides simple interface to ANOVA, including assumption checks.}
ezBoot { Computes bootstrap resampled cell means or lmer predictions}
ezCor { Function to plot a correlation matrix with scatterplots, linear fits, and univariate density plots}
ezDesign { Function to plot a visual representation of the balance of data given a specified experimental design. Useful for diagnosing missing data issues.}
ezMixed { Provides assessment of fixed effects in a mixed effects modelling context.}
ezPerm { Provides simple interface to the Permutation test.}
ezPlot { Uses the ggplot2 graphing package to generate plots for any given user-requested effect, by default producing error bars that facilitate visual post-hoc multiple comparisons.}
ezPlot2 { When supplied the results from a call to ezPredict or ezBoot, plots predictions with confidence intervals.}
ezPrecis { Provides a summary of a given data frame.}
ezPredict { Computes predicted values from the fixed effects of a mixed effects model.}
ezResample { Resamples data, useful when bootstrapping.}
ezStats { Provides between-Ss descriptive statistics for any given user-requested effect.}
progress_time { A progress bar that estimates time remaining.}
This package also contains two data sets:
ANT { Simulated data from the Attention Network Test}
ANT2 { Messy version of the ANT data set}See Also
ANT, ANT2, ezANOVA, ezBoot, ezCor, ezDesign, ezMixed, ezPerm, ezPlot, ezPlot2, ezPrecis, ezPredict, ezResample, ezStats, progress_time