Learn R Programming

ez (version 1.0)

ez-package: Easy analysis and visualization of factorial experiments.

Description

This package facilitates easy analysis of factorial experiments, including purely within-Ss designs (a.k.a. "repeated measures"), purely between-Ss designs, and mixed within-and-between-Ss designs. The functions in this package provide easy access to descriptive statistics (ezStats()), ANOVA (ezANOVA(), including non-parametric permutation tests), and visualization of results (ezPlot()).

Arguments

Details

ll{ Package: ez Type: Package Version: 1.0 Date: 2009-04-26 License: GPL-3 LazyLoad: yes } This package contains three useful functions. ezANOVA() provides simple interface to ANOVA (including assumption checks). ezStats() provides descriptive statistics for any given user-requested effect. ezPlot() uses the ggplot2 graphing package to generate plots for any given user-requested effect, by default producing error bars that facilitate visual post-hoc multiple comparisons.